@@ -66,7 +66,11 @@ class Parser:
         if tagName.startswith('attr'):
             ob_value = dom.attr('ob')
             is_not = False
+            is_two_way = False
             if ob_value:
+                if '@' in ob_value:
+                    ob_value = ob_value.replace('@', '')
+                    is_two_way = True
                 if ob_value.startswith('!'):
                     is_not = True
                     ob_value = ob_value.replace('!', '')
@@ -79,7 +83,7 @@ class Parser:
                     value = Computed([value], self.not_value)
             else:
                 value = dom.attr('v')
-            return self.AttributeObj(tagName.replace('attr-', ''), value, dom)
+            return self.AttributeObj(tagName.replace('attr-', ''), value, dom, is_two_way)
         
         if tagName.startswith('event'):
             name = dom.attr('v')
